package instance;

import java.util.List;

import util.TaskComparator;

/**
 * Simple class to model an instance of the crew scheduling problem, defined by
 * a list of depots and a list of timetabled tasks.
 * 
 * @author B.T.C. van Rossum
 */
public class Instance
{
	private final List<Integer> depots;
	private final List<Task> tasks;

	/**
	 * Initialises an instance with specified list of depots and tasks.
	 * 
	 * @param depots list of depots
	 * @param tasks  list of tasks
	 */
	public Instance(List<Integer> depots, List<Task> tasks)
	{
		this.depots = depots;
		this.tasks = tasks;
		sortTasks();
	}

	/**
	 * Returns list of depots.
	 * 
	 * @return list of depots
	 */
	public List<Integer> getDepots()
	{
		return depots;
	}

	/**
	 * Returns list of tasks.
	 * 
	 * @return list of tasks
	 */
	public List<Task> getTasks()
	{
		return tasks;
	}

	/**
	 * Topologically sort the list of tasks.
	 */
	public void sortTasks()
	{
		tasks.sort(new TaskComparator());
	}
}
